@@ -175,7 +175,8 @@ func (a *App) Diff(c DiffConfigProvider) error {
 		includeCRDs := !c.SkipCRDs()
 
 		prepErr := run.withPreparedCharts("diff", state.ChartPrepareOptions{
-			SkipRepos:              c.SkipDeps(),
+			SkipRepos:              c.SkipRefresh() || c.SkipDeps(),
+			SkipRefresh:            c.SkipRefresh(),
 			SkipDeps:               c.SkipDeps(),
 			IncludeCRDs:            &includeCRDs,
 			Validate:               c.Validate(),
@@ -240,7 +241,8 @@ func (a *App) Template(c TemplateConfigProvider) error {
 		run.helm.SetEnableLiveOutput(false)
 
 		prepErr := run.withPreparedCharts("template", state.ChartPrepareOptions{
-			SkipRepos:              c.SkipDeps(),
+			SkipRepos:              c.SkipRefresh() || c.SkipDeps(),
+			SkipRefresh:            c.SkipRefresh(),
 			SkipDeps:               c.SkipDeps(),
 			IncludeCRDs:            &includeCRDs,
 			SkipCleanup:            c.SkipCleanup(),
@@ -264,7 +266,8 @@ func (a *App) Template(c TemplateConfigProvider) error {
 func (a *App) WriteValues(c WriteValuesConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		prepErr := run.withPreparedCharts("write-values", state.ChartPrepareOptions{
-			SkipRepos:   c.SkipDeps(),
+			SkipRepos:   c.SkipRefresh() || c.SkipDeps(),
+			SkipRefresh: c.SkipRefresh(),
 			SkipDeps:    c.SkipDeps(),
 			SkipCleanup: c.SkipCleanup(),
 			Concurrency: c.Concurrency(),
@@ -315,7 +318,8 @@ func (a *App) Lint(c LintConfigProvider) error {
 		// `helm lint` on helm v2 and v3 does not support remote charts, that we need to set `forceDownload=true` here
 		prepErr := run.withPreparedCharts("lint", state.ChartPrepareOptions{
 			ForceDownload:          true,
-			SkipRepos:              c.SkipDeps(),
+			SkipRepos:              c.SkipRefresh() || c.SkipDeps(),
+			SkipRefresh:            c.SkipRefresh(),
 			SkipDeps:               c.SkipDeps(),
 			SkipCleanup:            c.SkipCleanup(),
 			Concurrency:            c.Concurrency(),
@@ -350,7 +354,8 @@ func (a *App) Fetch(c FetchConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		prepErr := run.withPreparedCharts("pull", state.ChartPrepareOptions{
 			ForceDownload:     true,
-			SkipRepos:         c.SkipDeps(),
+			SkipRefresh:       c.SkipRefresh(),
+			SkipRepos:         c.SkipRefresh() || c.SkipDeps(),
 			SkipDeps:          c.SkipDeps(),
 			OutputDir:         c.OutputDir(),
 			OutputDirTemplate: c.OutputDirTemplate(),
@@ -371,7 +376,8 @@ func (a *App) Sync(c SyncConfigProvider) error {
 		includeCRDs := !c.SkipCRDs()
 
 		prepErr := run.withPreparedCharts("sync", state.ChartPrepareOptions{
-			SkipRepos:              c.SkipDeps(),
+			SkipRepos:              c.SkipRefresh() || c.SkipDeps(),
+			SkipRefresh:            c.SkipRefresh(),
 			SkipDeps:               c.SkipDeps(),
 			Wait:                   c.Wait(),
 			WaitForJobs:            c.WaitForJobs(),
@@ -404,7 +410,8 @@ func (a *App) Apply(c ApplyConfigProvider) error {
 		includeCRDs := !c.SkipCRDs()
 
 		prepErr := run.withPreparedCharts("apply", state.ChartPrepareOptions{
-			SkipRepos:              c.SkipDeps(),
+			SkipRepos:              c.SkipRefresh() || c.SkipDeps(),
+			SkipRefresh:            c.SkipRefresh(),
 			SkipDeps:               c.SkipDeps(),
 			Wait:                   c.Wait(),
 			WaitForJobs:            c.WaitForJobs(),
@@ -466,7 +473,8 @@ func (a *App) Delete(c DeleteConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		if !c.SkipCharts() {
 			err := run.withPreparedCharts("delete", state.ChartPrepareOptions{
-				SkipRepos:     c.SkipDeps(),
+				SkipRepos:     c.SkipRefresh() || c.SkipDeps(),
+				SkipRefresh:   c.SkipRefresh(),
 				SkipDeps:      c.SkipDeps(),
 				Concurrency:   c.Concurrency(),
 				DeleteWait:    c.DeleteWait(),
@@ -489,7 +497,8 @@ func (a *App) Destroy(c DestroyConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		if !c.SkipCharts() {
 			err := run.withPreparedCharts("destroy", state.ChartPrepareOptions{
-				SkipRepos:     c.SkipDeps(),
+				SkipRepos:     c.SkipRefresh() || c.SkipDeps(),
+				SkipRefresh:   c.SkipRefresh(),
 				SkipDeps:      c.SkipDeps(),
 				Concurrency:   c.Concurrency(),
 				DeleteWait:    c.DeleteWait(),
@@ -516,7 +525,8 @@ func (a *App) Test(c TestConfigProvider) error {
 		}
 
 		err := run.withPreparedCharts("test", state.ChartPrepareOptions{
-			SkipRepos:   c.SkipDeps(),
+			SkipRepos:   c.SkipRefresh() || c.SkipDeps(),
+			SkipRefresh: c.SkipRefresh(),
 			SkipDeps:    c.SkipDeps(),
 			Concurrency: c.Concurrency(),
 		}, func() {
@@ -1006,14 +1016,14 @@ func printBatches(batches [][]state.Release) string {
 
 	w.Init(buf, 0, 1, 1, ' ', 0)
 
-	fmt.Fprintln(w, "GROUP\tRELEASES")
+	_, _ = fmt.Fprintln(w, "GROUP\tRELEASES")
 
 	for i, batch := range batches {
 		ids := []string{}
 		for _, r := range batch {
 			ids = append(ids, state.ReleaseToID(&r.ReleaseSpec))
 		}
-		fmt.Fprintf(w, "%d\t%s\n", i+1, strings.Join(ids, ", "))
+		_, _ = fmt.Fprintf(w, "%d\t%s\n", i+1, strings.Join(ids, ", "))
 	}
 
 	_ = w.Flush()
@@ -1028,13 +1038,13 @@ func printDAG(batches [][]state.Release) string {
 
 	w.Init(buf, 0, 1, 1, ' ', 0)
 
-	fmt.Fprintln(w, "GROUP\tRELEASE\tDEPENDENCIES")
+	_, _ = fmt.Fprintln(w, "GROUP\tRELEASE\tDEPENDENCIES")
 
 	for i, batch := range batches {
 		for _, r := range batch {
 			id := state.ReleaseToID(&r.ReleaseSpec)
 			needs := r.ReleaseSpec.Needs
-			fmt.Fprintf(w, "%d\t%s\t%s\n", i+1, id, strings.Join(needs, ", "))
+			_, _ = fmt.Fprintf(w, "%d\t%s\t%s\n", i+1, id, strings.Join(needs, ", "))
 		}
 	}
 
@@ -1537,6 +1547,7 @@ Do you really want to apply?
 					PostRenderer:     c.PostRenderer(),
 					PostRendererArgs: c.PostRendererArgs(),
 					SyncArgs:         c.SyncArgs(),
+					HideNotes:        c.HideNotes(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), syncOpts)
 			}))
@@ -1930,6 +1941,7 @@ Do you really want to sync?
 					PostRenderer:     c.PostRenderer(),
 					PostRendererArgs: c.PostRendererArgs(),
 					SyncArgs:         c.SyncArgs(),
+					HideNotes:        c.HideNotes(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), opts)
 			}))
