@@ -10,6 +10,7 @@ type ConfigProvider interface {
 	StripArgsValuesOnExitError() bool
 	DisableForceUpdate() bool
 	SkipDeps() bool
+	SkipRefresh() bool
 
 	FileOrDir() string
 	KubeContext() string
@@ -51,12 +52,14 @@ type ApplyConfigProvider interface {
 	PostRenderer() string
 	PostRendererArgs() []string
 	Cascade() string
+	HideNotes() bool
 	SuppressOutputLineRegex() []string
 
 	Values() []string
 	Set() []string
 	SkipCRDs() bool
 	SkipDeps() bool
+	SkipRefresh() bool
 	Wait() bool
 	WaitForJobs() bool
 
@@ -98,12 +101,14 @@ type SyncConfigProvider interface {
 	Args() string
 	PostRenderer() string
 	PostRendererArgs() []string
+	HideNotes() bool
 	Cascade() string
 
 	Values() []string
 	Set() []string
 	SkipCRDs() bool
 	SkipDeps() bool
+	SkipRefresh() bool
 	Wait() bool
 	WaitForJobs() bool
 	SyncArgs() string
@@ -132,6 +137,7 @@ type DiffConfigProvider interface {
 	Validate() bool
 	SkipCRDs() bool
 	SkipDeps() bool
+	SkipRefresh() bool
 
 	IncludeTests() bool
 
@@ -163,6 +169,7 @@ type DeleteConfigProvider interface {
 
 	Purge() bool
 	SkipDeps() bool
+	SkipRefresh() bool
 	SkipCharts() bool
 	DeleteWait() bool
 	DeleteTimeout() int
@@ -177,6 +184,7 @@ type DestroyConfigProvider interface {
 	Cascade() string
 
 	SkipDeps() bool
+	SkipRefresh() bool
 	SkipCharts() bool
 	DeleteWait() bool
 	DeleteTimeout() int
@@ -190,6 +198,7 @@ type TestConfigProvider interface {
 	Args() string
 
 	SkipDeps() bool
+	SkipRefresh() bool
 	Timeout() int
 	Cleanup() bool
 	Logs() bool
@@ -203,6 +212,7 @@ type LintConfigProvider interface {
 	Values() []string
 	Set() []string
 	SkipDeps() bool
+	SkipRefresh() bool
 	SkipCleanup() bool
 
 	DAGConfig
@@ -212,6 +222,7 @@ type LintConfigProvider interface {
 
 type FetchConfigProvider interface {
 	SkipDeps() bool
+	SkipRefresh() bool
 	OutputDir() string
 	OutputDirTemplate() string
 
@@ -228,6 +239,7 @@ type TemplateConfigProvider interface {
 	OutputDirTemplate() string
 	Validate() bool
 	SkipDeps() bool
+	SkipRefresh() bool
 	SkipCleanup() bool
 	SkipTests() bool
 	OutputDir() string
@@ -251,6 +263,7 @@ type WriteValuesConfigProvider interface {
 	Set() []string
 	OutputFileTemplate() string
 	SkipDeps() bool
+	SkipRefresh() bool
 	SkipCleanup() bool
 	IncludeTransitiveNeeds() bool
 
