@@ -24,6 +24,7 @@ type diffConfig struct {
 	validate                bool
 	skipCRDs                bool
 	skipDeps                bool
+	skipRefresh             bool
 	includeTests            bool
 	skipNeeds               bool
 	includeNeeds            bool
@@ -74,6 +75,10 @@ func (a diffConfig) SkipDeps() bool {
 	return a.skipDeps
 }
 
+func (a diffConfig) SkipRefresh() bool {
+	return a.skipRefresh
+}
+
 func (a diffConfig) IncludeTests() bool {
 	return a.includeTests
 }
