@@ -9,6 +9,7 @@ import (
 	"github.com/go-test/deep"
 
 	"github.com/helmfile/helmfile/pkg/environment"
+	"github.com/helmfile/helmfile/pkg/filesystem"
 )
 
 func boolPtrToString(ptr *bool) string {
@@ -128,6 +129,8 @@ func TestHelmState_executeTemplates(t *testing.T) {
 		tt := tests[i]
 		t.Run(tt.name, func(t *testing.T) {
 			state := &HelmState{
+				fs: &filesystem.FileSystem{
+					Glob: func(s string) ([]string, error) { return nil, nil }},
 				basePath: ".",
 				ReleaseSetSpec: ReleaseSetSpec{
 					HelmDefaults: HelmSpec{
@@ -226,6 +229,9 @@ func TestHelmState_recursiveRefsTemplates(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			state := &HelmState{
 				basePath: ".",
+				fs: &filesystem.FileSystem{
+					Glob: func(s string) ([]string, error) { return nil, nil },
+				},
 				ReleaseSetSpec: ReleaseSetSpec{
 					HelmDefaults: HelmSpec{
 						KubeContext: "test_context",
